@@ -382,7 +382,7 @@ sub get_watch_content ($git, $package) {
         $git =~ s/\.git$//;
         $watch = <<"EOW";
 version=4
-opts="filenamemangle=s%(?:.*?)?v?(\\d[\\d.]*\@ARCHIVE_EXT@)%\@PACKAGE@-\$1%" \\
+opts="filenamemangle=s%(?:.*?)?v?(\\d[\\d.]*\@ARCHIVE_EXT@)%\@PACKAGE\@-\$1%" \\
    $git/tags \\
    (?:.*?/)?v?\@ANY_VERSION@\@ARCHIVE_EXT@
 EOW
