@@ -58,7 +58,7 @@ sub read_git_credentials ($config, $file = "~/.git-credentials") {
     my $host = internal_config()->{api_host};
     if ($cred->is_file) {
         foreach my $line ($cred->lines) {
-            if ($line =~ m!https://(\w+):(\w+)\@$host$!) {
+            if ($line =~ m!https://([\w-]+):([\w-]+)\@$host$!) {
                 $config->{user} = $1;
                 $config->{private_token} = $2;
             }
